<?php
/**
 *  {$view_path}
 *
 *  @author     {$author}
 *  @package    Secioss
 *  @version    $Id$
 */

/**
 *  {$forward_name} view implementation.
 *
 *  @author     {$author}
 *  @access     public
 *  @package    Secioss
 */
class {$view_class} extends Secioss_ViewClass
{
    /**
     *  preprocess before forwarding.
     *
     *  @access public
     */
    function preforward()
    {
    }
}

?>
